# Postoi-resource

Create resource from Airtable

```

# publish to pypi

# 1. Add UV_PUBLISH_TOKEN to .env  

# 2. Build
uv build --no-sources

# 3. Publish
uv publish

# 4. Check
uv run --with <PACKAGE> --no-project -- python -c "import <PACKAGE>"

```